@@ -30,12 +30,10 @@ test_original (void)
   GError* err = NULL;
 
   buf = gdk_pixbuf_new_from_resource_at_scale ("/test/resource/cve-2015-4491.bmp", size, size, FALSE, &err);
-  if (skip_if_insufficient_memory (&err))
-    return;
-
-  g_assert_no_error (err);
-
-  g_object_unref (buf);
+  /* Image is corrupt because the rowstride * height mul overflows */
+  g_assert_error (err, GDK_PIXBUF_ERROR, GDK_PIXBUF_ERROR_CORRUPT_IMAGE);
+  g_assert_null (buf);
+  g_error_free (err);
 }
 
 static void
