@@ -46,7 +46,7 @@ test_fail_size (GFile *file,
 
   success = g_file_load_contents (file, NULL, (gchar **) &contents, &contents_length, NULL, &error);
   g_assert_no_error (error);
-  g_assert (success);
+  g_assert_true (success);
 
 #ifdef GDK_PIXBUF_USE_GIO_MIME
   {
@@ -54,7 +54,7 @@ test_fail_size (GFile *file,
 
     content_type = g_content_type_guess (filename, contents, contents_length, NULL);
     mime_type = g_content_type_get_mime_type (content_type);
-    g_assert (mime_type);
+    g_assert_nonnull (mime_type);
     loader = gdk_pixbuf_loader_new_with_mime_type (mime_type, &error);
     g_free (mime_type);
     g_free (content_type);
@@ -70,14 +70,14 @@ test_fail_size (GFile *file,
   }
 #endif
   g_assert_no_error (error);
-  g_assert (loader != NULL);
+  g_assert_true (loader != NULL);
 
   for (i = 0; i < contents_length; i += chunk_size)
     {
       success = gdk_pixbuf_loader_write (loader, &contents[i], MIN(chunk_size, contents_length - i), &error);
       if (!success)
         {
-          g_assert (error);
+          g_assert_nonnull (error);
           g_clear_error (&error);
           goto out;
         }
@@ -85,8 +85,8 @@ test_fail_size (GFile *file,
     }
   
   success = gdk_pixbuf_loader_close (loader, &error);
-  g_assert (!success);
-  g_assert (error);
+  g_assert_false (success);
+  g_assert_nonnull (error);
   g_clear_error (&error);
 
 out:
