@@ -109,7 +109,7 @@ find_format (const gchar *filename, gchar **found_format)
             }
         }
 
-      g_free (extensions);
+      g_strfreev (extensions);
       if (retval)
         break;
     }
@@ -296,6 +296,8 @@ add_test_for_all_images (const gchar   *prefix,
       test_path = g_strconcat (prefix, "/", relative_path, NULL);
       
       g_test_add_data_func_full (test_path, g_object_ref (file), test_func, g_object_unref);
+      g_free (relative_path);
+      g_free (test_path);
       return;
     }
 
